:html_theme.sidebar_secondary.remove:
:notoc:

TidyMS2
=======

A toolkit for creating Mass Spectrometry preprocessing workflows.


Install it using any of the following methods:

.. include:: installation.rst

and get started with the :ref:`user-guide`

.. toctree::
   :maxdepth: 2
   :hidden:

   guides
   overview
   api
   algorithms
   glossary
   developer
